class Multa(object):

    def __init__(self, multa):
        self.TituloCodigoMulta = None
        self.TituloDataMulta = None
        self.TituloValorMultaTaxa = None
